// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef ACTION_MSGS__MSG__GOAL_STATUS_ARRAY_HPP_
#define ACTION_MSGS__MSG__GOAL_STATUS_ARRAY_HPP_

#include "action_msgs/msg/detail/goal_status_array__struct.hpp"
#include "action_msgs/msg/detail/goal_status_array__builder.hpp"
#include "action_msgs/msg/detail/goal_status_array__traits.hpp"
#include "action_msgs/msg/detail/goal_status_array__type_support.hpp"

#endif  // ACTION_MSGS__MSG__GOAL_STATUS_ARRAY_HPP_
